<?php namespace Core\Kernel;

/* Created: HM:Script
*  Website: http://hmscript.net
*     User: ZpVs
*     Date: 23.04.13
*     Time: 16:05
*  Version: 1.0.0
*   Script: hStation CMS
*/
class HmsCore
{
    public $state = true;
    const CONTPATH = 'content/';
    const COREPATH = 'core/kernel/';
    const ENGPATH = 'core/engine/';
    public static $dbs = null;
    public static $session = null;
    public static $user = null;
    public static $mailer = null;
    public static $engine = null;
    public static $template = null;
    public static $access = null;
    public $kernel = 'dbs:session:mailer:engine:user:templates:access';
    public $console = array();

    /**
     * Check for the availability of the kernel to boot.
     * If true - More kernel boot enabled.
     * If false - Further kernel boot prohibited.
     **/
    public function __construct($kernel_mod = null)
    {
        mf_unGlobal();
        ($kernel_mod == null)?$activated_mods=$this->kernel:$activated_mods=$kernel_mod;
        $this->initNeededModules($activated_mods);
    }
    /**
     * connection and initialization of classes required for the further work of the nucleus
     **/
    protected function initNeededModules($mods)
    {
        $i_mods = explode(':', $mods);
        foreach ($i_mods as $modules) {
               $this->initKernelModules($modules);
        }
    }
    protected function initKernelModules($need_mods)
    {
        switch ($need_mods) {
            case 'dbs':
                $this->initDB();
                break;
            case 'session':
                $this->initSession();
                break;
            case 'user':
                $this->initUser();
                break;
            case 'mailer':
                $this->initMailer();
                break;
            case 'engine':
                $this->initEngine();
                break;
            case 'templates':
                $this->initTemplates();
                break;
            case 'access':
                $this->initAccess();
                break;
        }
    }

    /**
     * Проверка состояние подключения класса работы с  базой данных.
     * Если  null - Инициализируем класс.
     * Если  уже инициализирован возвращаем екземпляр класса.
     **/
    protected static function initDB()
    {
        if (self::$dbs == null) {
            self::$dbs = new \Core\Kernel\HmsDbs;
            self::initLang();
        }

        return self::$dbs;
    }
    /**
     * Проверка состояние подключения класса работы с
     * сесиями пользователей.
     * Если  null - Инициализируем класс.
     * Если  уже инициализирован возвращаем екземпляр класса.
     **/
    protected static function initSession()
    {
        if (self::$session == null) {
            self::$session = new \Core\Kernel\HmsSession;
        }

        return self::$session;
    }
    /**
     * Проверка состояние подключения класса работы с
     * пользователями.
     * Если  null - Инициализируем класс.
     * Если  уже инициализирован возвращаем екземпляр класса.
     **/
    protected static function initUser()
    {
        if (self::$user == null) {
            self::$user = new \Core\Kernel\HmsUser('', '', '', '', '', '', '', '', '');
        }

        return self::$user;
    }
    /**
     * Проверка состояние подключения класса
     * работы почтового робота.
     * Если  null - Инициализируем класс.
     * Если  уже инициализирован возвращаем екземпляр класса.
     **/
    protected static function initMailer()
    {
        if (self::$mailer == null) {
            self::$mailer = new \Core\Kernel\HmsMailer;
        }

        return self::$mailer;
    }
    /**
     * Проверка состояние подключения класса
     * работы инструментов ядра.
     * Если  null - Инициализируем класс.
     * Если  уже инициализирован возвращаем екземпляр класса.
     **/
    protected static function initEngine()
    {
        if (self::$engine == null) {
            self::$engine = new \Core\Kernel\HmsEngine;
        }

        return self::$engine;
    }
    /**
     * Проверка состояние подключения класса
     * инициализации обработчика шаблонов отображения.
     * Если  null - Инициализируем класс.
     * Если  уже инициализирован возвращаем екземпляр класса.
     **/
    protected static function initTemplates()
    {
        global $defaultTemplatesSettings;
        if (self::$template == null) {
            self::$template = new \Core\Kernel\HmsTemplate($defaultTemplatesSettings);
        }

        return self::$template;
    }
    /**
     * Проверка состояние подключения класса
     * инициализации доступа к  ядру или его инструментов.
     * Если  null - Инициализируем класс.
     * Если  уже инициализирован возвращаем екземпляр класса.
     **/
    protected static function initAccess()
    {
        if (self::$access == null) {
            self::$access = new \Core\Kernel\HmsAccess;
        }

        return self::$access;
    }
    public function initLang()
    {
        include_once (self::ENGPATH.'language/'.self::$dbs->d_cfg["site_language"].'/strings.php');
    }
}
