<?php namespace Core\Kernel;

/* Created: HM:Script
*  Website: http://hmscript.net
*     User: ZpVs
*     Date: 23.04.13
*     Time: 16:05
*  Version: 1.0.0
*   Script: hStation CMS
*/

class HmsSession extends \Core\Kernel\HmsCore
{
    public $state = false;
    public $session_domain = '';
    /**
     * Старт сесии и применение необходимых параметров
     **/
    public function __construct()
    {
        session_start();
        $this->convertSessionFromCookie();
        header("Cache-Control: no-store, no-cache, must-revalidate");
        header("Expires: " . date("r"));
        header("X-Frame-Options: SAMEORIGIN");
        $this->getState();
        $this->session_domain = $this::$dbs->d_cfg['cookie_domain'];
    }
    public function convertSessionFromCookie()
    {
        if (isset($_SESSION['errors'])) {
                setcookie("errors", $_SESSION['errors'], time()+3, "/", $this->session_domain);
            unset($_SESSION['errors']);
        }
        if (isset($_SESSION['success'])) {
            setcookie("success", $_SESSION['success'], time()+3, "/", $this->session_domain);
            unset($_SESSION['success']);
        }
    }
    public function addSessionValue($key, $value)
    {
        switch ($key) {
            case 'errors':
                $_SESSION[$key] = $value;
                break;
            case 'success':
                $_SESSION[$key] = $value;
                break;
            default:
                $_SESSION[$key] = $value;
                setcookie($key, $value, time()+60*60*1, "/", $this->session_domain);

        }
    }
    public function updateSessionValue($key, $value)
    {
        if (array_key_exists($key, $_SESSION)) {
            $_SESSION[$key] = $value;
        }
        setcookie($key, $value, time()+60*60*24*1, "/", $this->session_domain);
    }
    public function deleteSessionValue($key)
    {
        if (array_key_exists($key, $_SESSION)) {
            unset($_SESSION[$key]);
        }
        setcookie($key, '', time() - 3600, "/", $this->session_domain);

    }
    /**
     * Проверка состояния авторизации пользователя.
     * true - авторизован false - не авторизован
     **/
    public function getState()
    {
        if (isset($_SESSION['status'])) {
            switch ($_SESSION['status']) {
                case 'approved':
                    if (isset($_COOKIE['status'])) {
                        switch ($_COOKIE['status']) {
                            case 'approved':
                                $this->state = true;
                                break;
                            default:
                                $this->state = false;
                        }
                    }
                    break;
                default:
                    $this->state = false;
            }
        }

        return $this->state;
    }
    /**
     * Авторизация пользователя.
     * Если checkUser возвращает true - авторизовывать и
     * перенаправлять на страницу на которой нажат вход.
     * Если checkUser возвращает false - не авторизовывать и
     * перенаправлять на страницу авторизации.
     **/
    public function auth($user)
    {
        global $core;
        if ($core::$dbs->checkAuthUser(mf_guard($user["email"]), md5($user["password"]))) {
            $userKEY = $core::$dbs->getUserKey(mf_guard($user["email"]));
            $this->addSessionValue('status', 'approved');
            $this->addSessionValue('unikey', $userKEY);

            if ($user["remember"] == '1') {
                setcookie('unikey', $userKEY, time()+60*60*24*90, "/", $this->session_domain);
                setcookie('status', 'approved', time()+60*60*24*90, "/", $this->session_domain);
            }
            $core::$user = $core::$dbs->getOneUser();
            return true;
        } else {
            return false;
        }
    }
    /**
     * Авторизация пользователя.
     * Если checkUser возвращает true - авторизовывать и
     * перенаправлять на страницу на которой нажат вход.
     * Если checkUser возвращает false - не авторизовывать и
     * перенаправлять на страницу авторизации.
     **/
    public function authSocial($user, $username = '')
    {
        global $core;
        if ($core::$dbs->checkAuthUserSocial(mf_guard($user))) {
            $userKEY = $core::$dbs->getUserKey(mf_guard($user));
            $this->addSessionValue('status', 'approved');
            $this->addSessionValue('unikey', $userKEY);
            $core::$user = $core::$dbs->getOneUser();
            if (!empty($username)) {
                $core::$user->setName($username);
            }
            return true;
        } else {
            return false;
        }
    }
    /**
     * Завершение пользовательской авторизации и
     * уничтожения данных сессии.
     **/
    public function destroyAuth()
    {
        foreach ($_COOKIE as $cookie_key => $cookie_value) {
            $this->deleteSessionValue($cookie_key);
        }
        unset($_SESSION);
        session_destroy();
        $this->state = false;
    }
}
